Package: semmcci
Title: Monte Carlo Confidence Intervals in Structural Equation Modeling
Version: 1.1.4
Authors@R: c(
    person(given = "Ivan Jacob Agaloos",
           family = "Pesigan",
           role = c("aut", "cre", "cph"),
           email = "r.jeksterslab@gmail.com",
           comment = c(ORCID = "0000-0003-4818-8420")),
    person(given = "Shu Fai",
           family = "Cheung",
           role = "ctb",
           email = "shufai.cheung@gmail.com",
           comment = c(ORCID = "0000-0002-9871-9448"))
    )
Description: Monte Carlo confidence intervals for free and defined parameters
    in models fitted in the structural equation modeling package 'lavaan'
    can be generated using the 'semmcci' package.
    'semmcci' has three main functions, namely, MC(), MCMI(), and MCStd().
    The output of 'lavaan' is passed as the first argument
    to the MC() function or the MCMI() function to generate Monte Carlo confidence intervals.
    Monte Carlo confidence intervals for the standardized estimates
    can also be generated by passing the output of the MC() function or the MCMI() function
    to the MCStd() function.
    A description of the package and code examples
    are presented in Pesigan and Cheung (2023) <doi:10.3758/s13428-023-02114-4>.
URL: https://github.com/jeksterslab/semmcci,
        https://jeksterslab.github.io/semmcci/
BugReports: https://github.com/jeksterslab/semmcci/issues
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
Depends: R (>= 3.0.0)
Imports: stats, lavaan, mice, parallel
Suggests: knitr, rmarkdown, testthat, MASS, psych, Amelia, bmemLavaan
RoxygenNote: 7.3.1
Author: Ivan Jacob Agaloos Pesigan [aut, cre, cph]
    (<https://orcid.org/0000-0003-4818-8420>),
  Shu Fai Cheung [ctb] (<https://orcid.org/0000-0002-9871-9448>)
Maintainer: Ivan Jacob Agaloos Pesigan <r.jeksterslab@gmail.com>
Built: R 4.4.1; ; 2024-09-15 15:58:19 UTC; unix
